%% MEA Tutorial 7 - Part 2: MATLAB/Simulink

clc;
clear all;
close all;

%% Parameters

r1    = 6.75e-2;
r2    = 3.6e-2;
r3    = 3.57e-2;
r4    = 1.4e-2;
alpha = 20*pi/180;
Ll    = 11.4e-2;                % length of the motor
N     = 72;
mur   = 4000;
mu0   = 4e-7*pi;
I_max = 10;
U_DC  = 500;
omega = 50;
R_el  = 0.0;
shift = 0;                     % in degrees
shift = shift*pi/180;
Tsim  = 2*(2*pi/omega);
P     = 1;

%% Geometrical parameters

bp   = r3*alpha;                % Width of the pole schoe
Ap   = bp*Ll;                   % cross-sectional area of the pole schoe
lps  = r1-r2;                   % length of the stator pole schoe
lpr  = r3-r4;                   % length of the rotor pole schoe

lpl  = r2-r3;                   % length of the air gap, totally aligned
l2   = lpl; 
l_23 = lpl;

l1   = r2-r4;                   % length of the air gap, totally unaligned
l_24 = l1;

ls   = pi*r1;                   % length of the yoke path (one side)



%% Reluctances

RPS = lps / (mu0*mur*Ap);       % magn. resistance of the stator pole shoe
RPR = lpr / (mu0*mur*Ap);       % magn. resistance of the rotor pole shoe
RPL = lpl / (mu0*Ap);           % magn. resistance of the air gap, totally aligned  
RS  = ls  / (mu0*mur*Ap);       % magn. resistance of the yoke (one side)
RFE = 2*RPS+2*RPR+RS/2;         % total magn. resistance of the iron paths 
R1  = l1/mu0/Ap;
R2  = l2/mu0/Ap;


%% Plot of reluctance and inductance

steps=1000;
h=alpha/(steps-1);
phi=0:h:alpha;                  % rotor angle in degree
RL=2*alpha*l1*l2./(mu0*bp*Ll.*((alpha-phi).*l1+phi.*l2));
phi=0:h:pi;
R=ones(1,length(phi))*(2*R1+RFE);
R(1:alpha/h+1)=RL+RFE;
R(end-alpha/h:end)=RL(end:-1:1)+RFE;
R=[R R];
phi=0:h:2*pi+h;
L=(2*N)^2./R;
figure('NumberTitle','off','name','Reluctance and inductance');
[AX,H1,H2]=plotyy(phi,R,phi,L);
set(get(AX(1),'Ylabel'),'String','{\itR} in A/(Vs)');
set(get(AX(2),'Ylabel'),'String','{\itL} in H');
set(AX(1),'XTick',[0 alpha pi-alpha pi pi+alpha 2*pi-alpha 2*pi])
set(AX(2),'XTick',[]);
set(AX(1),'XTickLabel',{'0' 'alpha' 'pi-alpha' 'pi' 'pi+alpha' '2*pi-alpha' '2*pi'})
grid on;
%ylabel('{\itT} in Nm');
xlabel('{\it\phi}');


%% Flux in dependence of different angles

figure('NumberTitle','off','Name','Flux in dependence of different angles');
hold on;
i_var=0:0.1:I_max;
winkel=[0,alpha/2/pi*180,alpha/pi*180];
col=['b','r','g'];
lstr='';
for i=1:length(winkel)
	L_var=L(find(phi/pi*180>=winkel(i),1));
	psi_var=L_var*i_var;
% 	eval(['plot(i_var,psi_var,''',col(i),''')']);
    plot(i_var,psi_var,'color',col(i))
	lstr=[lstr,'''\Psi(',num2str(winkel(i)),'\circ)'','];
end
grid on;
lstr=lstr(1:length(lstr)-1);
eval(['legend(',lstr,')']);
xlabel('\it{i} in A');
ylabel('{\it\Psi} in Vs');


%% Torque

i=I_max;
steps=1000;
h=alpha/(steps-1);
phi=0:h:alpha;           % Rotorwinkel in Grad
TP=(1/2)*i^2*(alpha*bp*(2*N)^2*l1*2*l2*Ll*mu0*(l1-l2))./(phi.*bp*(l1-l2)*Ll*mu0*RFE-alpha*(bp*Ll*mu0*RFE+2*l2)*l1).^2;
TN=-(1/2)*i^2*(alpha*bp*(2*N)^2*l1*2*l2*Ll*mu0*(l1-l2))./(phi.*bp*(l1-l2)*Ll*mu0*RFE-alpha*(bp*Ll*mu0*RFE+2*l2)*l1).^2;
phi2=alpha:h:pi-alpha;
T0=ones(1,length(phi2))*0;
T=[TN T0 TP TN T0 TP];
phi=linspace(0,2*pi,length(T));

figure('NumberTitle','off','name','Torque');
plot(phi,T);
set(gca,'XTick',[0 alpha pi-alpha pi pi+alpha 2*pi-alpha 2*pi]);
set(gca,'XTickLabel',{'0' 'alpha' 'pi-alpha' 'pi' 'pi+alpha' '2*pi-alpha' '2*pi'});
grid on;
ylabel('{\itT} in Nm');
xlabel('{\it\phi}');


